<template>
  <PageLayoutWithBg class="index-page-wrapper" :title="'生活缴费'" :need-auth="false">
    <ContentView>
      <RechargeGrid @phoneBillRecharge="goPhoneBillRecharge" />
    </ContentView>
  </PageLayoutWithBg>
</template>

<script setup lang="ts">
import { useUser, useAccessLogin } from '@/hooks';
import { useUserStore } from '@/stores/modules/user';
import Taro from '@tarojs/taro';
import IconLogo from '@/assets/home/icon-logo.png';
import { OrderInputType } from '@life-payment/constants';
import { RechargeGrid } from '@life-payment/components';

const goPhoneBillRecharge = useAccessLogin(() => {
  Taro.navigateTo({
    url: `${RouterPath.phoneBillRecharge}`,
  });
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.index-page-wrapper {
  .menu-logo {
    padding: 0;

    .logo {
      width: 96px;
      height: 64px;
    }
  }

  .home-searchbar-wrapper {
    padding: 32px 0;
    display: flex;

    .searchbar-container {
      flex: 1;
      min-width: 0;
    }

    .city-btn {
      display: flex;
      align-items: center;
      padding-left: 36px;
      color: boleGetCssVar('text-color', 'primary');

      .city-btn-icon {
        width: 40px;
        height: 40px;
      }

      .city-btn-text {
        max-width: 200px;
        @include ellipsis;
        margin-left: 12px;
        font-size: 30px;
      }
    }
  }

  .home-banner-wrapper {
    .banner-img {
      width: 100%;
      height: 260px;
      object-fit: cover;
    }
  }

  .home-header {
    padding: 0 boleGetCssVar('size', 'body-padding-h');
  }
}

.home-list {
  @include infiniteLoadingInTabBarPage;
}
</style>
